@@ -125,22 +125,23 @@ class Serializer(base.Serializer):
         self.use_natural_keys = options.get("use_natural_keys", False)
         if self.write_preamble:
             self.stream.write('# -*- coding: UTF-8 -*-\n')
-            name,current_version,url = settings.SITE.using().next()
+            #~ name,current_version,url = settings.SITE.using().next()
+            current_version = settings.SITE.version
             if '+' in current_version:
                 logger.warning(
                     "Dumpdata from intermediate version %s" % current_version)
             
             self.stream.write('''\
 """
-This is a `Python dump <http://north.lino-framework.org>`_.
-
-''')
-            self.stream.write(settings.SITE.welcome_text())
+This is a `Python dump <http://north.lino-framework.org>`_
+created using %s.
+''' % settings.SITE.using_text())
+            #~ self.stream.write(settings.SITE.welcome_text())
             self.stream.write('''
 """
 from __future__ import unicode_literals
 ''')
-            self.stream.write('SOURCE_VERSION = %r\n' % current_version)
+            self.stream.write('SOURCE_VERSION = %r\n' % str(current_version))
             self.stream.write('from decimal import Decimal\n')
             self.stream.write('from datetime import datetime as dt\n')
             self.stream.write('from datetime import time,date\n')
@@ -636,6 +637,7 @@ See <https://code.djangoproject.com/ticket/18213>.
             Don't raise an exception. The unsaved instances got lost and 
             the loaddata should be done again, but meanwhile the database
             is not necessarily invalid and may be used for further testing.
+            And anyway, loaddata would catch it and still continue.
             """
             #~ raise Exception(msg)
             
